#include "compat.h"
#include "can.h"

#define swap(data) (((data << 8) & 0xFF00) | ((data >> 8) & 0x00FF))

int CAN_initialize_board
    (
    int addr
    )
    {
    return(canHwInit(addr));
    }

int CAN_start_chip
    (
    void
    )
    {
    return(0);
    }


int CAN_reset_board
    (
    void
    )
    {
    return(canHwReset());
    }


int CAN_enable_fifo
    (
    void
    )
    {
    return(0);
    }


int CAN_set_acceptance
    (
    int code,
    int mask
    )
    {
    static char filter[2048];
    int l;
    code = code << 3;
    mask = mask << 3;
    for(l=0;l<2048;l++)
	{
	if ((l & mask) == (code & mask))
	    {
	    if (filter[l] == 0)
		{
		canEnableId(0,l);
		filter[l] = 1;
		}
	    }
	else
	    {
	    if (filter[l] == 1)
		{
		canDisableId(0,l);
		filter[l] = 0;
		}
	    }
	}
    return(0);
    }


int CAN_set_acceptance2
    (
    int code,
    int mask
    )
    {
    static char filter[2048];
    int l;
    code = code << 3;
    mask = mask << 3;
    for(l=0;l<2048;l++)
	{
	if ((l & mask) == (code & mask))
	    {
	    if (filter[l] == 0)
		{
		canEnableId(1,l);
		filter[l] = 1;
		}
	    }
	else
	    {
	    if (filter[l] == 1)
		{
		canDisableId(1,l);
		filter[l] = 0;
		}
	    }
	}
    return(0);
    }


int CAN_tx_ack_flag[8]={0,0,0,0,0,0,0,0};

int CAN_enable_fifo_transmit_ack
    (
    void
    )
    {
    CAN_tx_ack_flag[0] = 1;
    return(0);
    };


int CAN_enable_fifo_transmit_ack2
    (
    void
    )
    {
    CAN_tx_ack_flag[1] = 1;
    return(0);
    }


int CAN_read
    (
    param_struct*  param
    )
    {
    CAN_MSG msg;
    int     l;

    if (canMsg(&msg) == -1)
	return(0);
    if (msg.cmmd == CAN_HM_BCAN)
	{
	param->Ident      = swap(msg.id);
	param->Can        = swap(msg.net);
	param->DataLength = swap(msg.len);
	if (param->DataLength > 8)
	    {
	    param->DataLength -= 16;
	    return(2);
	    }
	for (l=0;l<8;l++)
	    param->RCV_data[l] = msg.data[l];
	return(1);
	}
    if (msg.cmmd == CAN_HM_TXDONE)
	{
	if (CAN_tx_ack_flag[msg.id & 0x07] == 0)
	    return(0);
	param->Ident      = swap(msg.id);
	param->Can        = swap(msg.net);
	param->DataLength = swap(msg.len);
	if (param->DataLength > 8)
	    {
	    param->DataLength -= 16;
	    return(8);
	    }
	return(3);
	}
    if (msg.cmmd == CAN_HM_ERROR)
	{
	if ((msg.data[5] != 0) || (msg.data[7] != 0))
	    {
	    param->RecOverrun_flag = 1;
	    return(7);
	    }
	if (msg.data[1] == 0xc0)
	    param->Bus_state = 2;
	if (msg.data[1] == 0x80)
	    param->Bus_state = 1;
	if (msg.data[1] == 0x00)
	    param->Bus_state = 0;
	return(5);
	}
    if (msg.cmmd == CAN_HM_TXTOUT)
	{
	return(6);
	}
    return(0);
    }


int CAN_send_data
    (
    int            id,
    int            length,
    unsigned char* data
    )
    {
    return(canWrite(0,id,length,data));
    }


int CAN_send_data2
    (
    int            id,
    int            length,
    unsigned char* data
    )
    {
    return(canWrite(1,id,length,data));
    }


int CAN_send_remote
    (
    int   id,
    int   length
    )
    {
    unsigned char dummy[8];
    return(canWrite(0,id,length+0x10,&dummy[0]));
    }


int CAN_send_remote2
    (
    int   id,
    int   length
    )
    {
    unsigned char dummy[8];
    return(canWrite(1,id,length+0x10,&dummy[0]));
    }
