//************************************************************************
//*                                                                      *
//*   Header File for esd DOS can-driver                                 *
//*                                                                      *
//*----------------------------------------------------------------------*
//*                                                                      *
//*      Filename:       CAN.H                                           *
//*      Date:           28-MAY-97                                       *
//*      Language:       Borland C++ V 3.1                               *
//*      Dev.system:     IBM PC  / DOS                                   *
//*                                                                      *
//*      Purpose:        Header file for DOS CAN interface Routines      *
//*                                                                      *
//*----------------------------------------------------------------------*
//* Rev. | Released | Programmer  | Comments                             *
//*----------------------------------------------------------------------*
//* 1.00 | 28.05.97 | Ar          | Initial Release                      *
//************************************************************************



#define CAN_HM_BCAN    0     // Tx Request or Rx Data
#define CAN_HM_ENABLE  1     // Enable ID
#define CAN_HM_DISABLE 2     // Disable ID
#define CAN_HM_TIMEOUT 3     // Timeout for waiting for Data on a given ID
#define CAN_HM_BAUD    4     // Set Baudrate for a Net
#define CAN_HM_TXDONE  5     // Answer for Tx Req if data are send
#define CAN_HM_UNUSED1 6
#define CAN_HM_UNUSED2 7
#define CAN_HM_HNTOUT  8     // Global Timeout request/answer
#define CAN_HM_HNTCAN  9     // Global Timeout cancel
#define CAN_HM_CANEVT  10    // only for Board wit additional hardware
#define CAN_HM_TXTOUT  11    // Answer if Tx can't done within a second
#define CAN_HM_ERROR   12    // Errors from CAN Chip or Firmware
#define CAN_HM_BOARDID 13    // Board ID as first message

typedef struct
    {
    unsigned char cmmd;
    unsigned char net;
    short         id;
    short         len;
    unsigned char data[8];
    short         x1;
    short         x2;
    short         x3;
    } CAN_MSG;


int canHwInit      // init the hardware, set port base addr
    (
    int port       // port base addr, see list for ISA-200, selected for ISA-33.
    );             // for PCI-331 and PCI-360 the routine selects base automaticly.


int canHwReset     // reset the hardware, only need if no IRQ used
    (              // used instead of canIrqEnable
    void           // dummy for ISA-200, as this board must be use with IRQ
    );


int canEnableIrq   // enable IRQ for CAN board
    (              // level is a dummy for PCI-331 and PCI-360
    int level      // as this boards use PCI assigned IRQ
    );


int canDisableIrq  // disable IRQ for CAN board (cleanup)
    (
    void
    );


int canInit       // set baudrate for a given net
    (
    int net,      // net number
    int baudrate  // set table in printed docu
    );


int canEnableId   // enables ID for recieving DATA and RTR
    (             // is counting, if you call enable twice for an ID,
    int net,      // you had to call disable twice too.
    int id        // after board reset, all ID's are disabled
    );

int canDisableId  // Disables ID again
    (
    int net,
    int id
    );

int canMsg        // Read next message, do not use as knowlege of
    (             // fifo data structure is nessary
    CAN_MSG* msg
    );

int canRead      // Read next message from CAN Board
    (
    int*           net,
    int*           id,
    int*           length,
    unsigned char* data
    );


int canWrite     // Write data do CAN-bus
    (
    int            net,
    int            id,
    int            length,
    unsigned char* data
    );
