//************************************************************************
//*                                                                      *
//*   Header File for esd DOS can-driver                                 *
//*                                                                      *
//*----------------------------------------------------------------------*
//*                                                                      *
//*      Filename:       CAN.H                                           *
//*      Date:           28-MAY-97                                       *
//*      Language:       Borland C++ V 3.1                               *
//*      Dev.system:     IBM PC  / DOS                                   *
//*                                                                      *
//*      Purpose:        Header file for DOS CAN interface Routines      *
//*                                                                      *
//*----------------------------------------------------------------------*
//* Rev. | Released | Programmer  | Comments                             *
//*----------------------------------------------------------------------*
//* 1.00 | 28.05.97 | Ar          | Initial Release                      *
//* 1.10 | 30.06.97 | Ar          | For CAN 2.0B                         *
//* 1.20 | 05.08.97 | Ar          | Firmware update included             *
//* 1.30 | 12.08.97 | Ar          | Firmware Verify                      *
//* 1.40 | 12.10.97 | Ar          | For c++ and 16 Bit DLL               *
//* 1.41 | 23.12.97 | Ar          | Hardware Revison                     *
//************************************************************************

#ifndef EXPORT
#define EXPORT
#endif
#ifndef DIST
#define DIST
#endif

#ifdef __cplusplus
extern "C" {
#endif

#define CAN_HM_BCAN      0   // Tx Request or Rx Data
#define CAN_HM_ENABLE    1   // Enable ID
#define CAN_HM_DISABLE   2   // Disable ID
#define CAN_HM_TIMEOUT   3   // Timeout for waiting for Data on a given ID
#define CAN_HM_BAUD      4   // Set Baudrate for a Net
#define CAN_HM_TXDONE    5   // Answer for Tx Req if data are send
#define CAN_HM_UNUSED1   6
#define CAN_HM_UNUSED2   7
#define CAN_HM_HNTOUT    8   // Global Timeout request/answer
#define CAN_HM_HNTCAN    9   // Global Timeout cancel
#define CAN_HM_CANEVT    10  // only for Board wit additional hardware
#define CAN_HM_TXTOUT    12  // Answer if Tx can't done within a second
#define CAN_HM_ERROR     13  // Errors from CAN Chip or Firmware
#define CAN_HM_BOARDID   14  // Board ID as first message
#define CAN_HM_EX_BCAN   15  // Extended Tx Request or Rx Data
#define CAN_HM_EX_TXDONE 16  // Board ID as first message
#define CAN_HM_EX_TXTOUT 17  // Extended Tx Timeout
#define CAN_HM_EX_BAUD   18  // Set Baud by BT0/BT1 Register Para
#define CAN_HM_EX_FILTER 19  // Set Filter for Extended Frames
#define CAN_HM_HWREVI    20  // Board Hardware Revision
#define CAN_HM_FLASH     128 // Enter Flash Prog Mode
#define CAN_HM_FERASE    129 // Erase Sector
#define CAN_HM_FPROG     130 // Prog a few Bytes
#define CAN_HM_FEXIT     131 // Exit Flash Prog Mode
#define CAN_HM_PROG1     132 // New Flash Prog Command
#define CAN_HM_FPVERIFY  133 // Verfy Flash Data
#define CAN_HM_FPREVI    134 // Set HW Revision

typedef struct
    {
    unsigned char  cmmd;
    unsigned char  net;
    short          id;
    short          len;
    unsigned char  data[8];
    unsigned short x1;
    unsigned short x2;
    unsigned short x3;
    } CAN_MSG;


int EXPORT canHwInit               // init the hardware, set port base addr
    (
    int port                       // port base addr, see list for ISA-200, selected for ISA-33.
    );                             // for PCI-331 and PCI-360 the routine selects base automaticly.


int EXPORT canHwReset              // reset the hardware, only need if no IRQ used
    (                              // used instead of canIrqEnable
    void                           // dummy for ISA-200, as this board must be use with IRQ
    );


int EXPORT canEnableIrq            // enable IRQ for CAN board
    (                              // level is a dummy for PCI-331 and PCI-360
    int level                      // as this boards use PCI assigned IRQ
    );


int EXPORT canDisableIrq           // disable IRQ for CAN board (cleanup)
    (
    void
    );


int EXPORT canInit                 // set baudrate for a given net
    (
    int net,                       // net number
    int baudrate                   // set table in printed docu
    );


int EXPORT canInitEx               // set baudrate for a given net
    (
    int net,                       // net number
    int bt0_bt1                    // value for bt0 and bt1 Register
    );


int EXPORT canEnableId             // enables ID for recieving DATA and RTR
    (                              // is counting, if you call enable twice for an ID,
    int net,                       // you had to call disable twice too.
    int id                         // after board reset, all ID's are disabled
    );


int EXPORT canDisableId            // Disables ID again
    (
    int net,
    int id
    );


int EXPORT canSetAcceptanceEx      // Set Filter for exrended Messages
    (
    int net,
    int handle,                    // must be zero for future extension
    long mask,                     // mask id with this value
    long id                        // then compare with this value
    );


int EXPORT canMsg                  // Read next message, do not use as knowlege of
    (                              // fifo data structure is nessary
    CAN_MSG DIST* msg
    );


int EXPORT canCmmd                 // Write message, do not use as knowlege of
    (                              // fifo data structure is nessary
    CAN_MSG DIST* msg
    );


int EXPORT canRead                 // Read next message from CAN Board
    (
    int DIST*           net,
    int DIST*           id,
    int DIST*           length,
    unsigned char DIST* data
    );


int EXPORT canReadEx               // Read next message from CAN Board
    (
    int DIST*           net,
    long DIST*          id,
    int DIST*           length,
    unsigned char DIST* data
    );


int EXPORT canWrite                // Write data do CAN-bus
    (
    int                 net,
    int                 id,
    int                 length,
    unsigned char DIST* data
    );


int EXPORT canWriteEx              // Write data do CAN-bus
    (
    int                 net,
    long                id,
    int                 length,
    unsigned char DIST* data
    );

int EXPORT canUpdateFirmware       // Update Firmware on CAN Board
    (
    unsigned char DIST* key,       // Key for Firmware update
    unsigned char DIST* firmware,  // Pointer to new Firmware
    unsigned long       length,    // length of new firmware
    unsigned long       block,     // Flash offset for Firmware
    unsigned long       blocksize  // Size of Block for erase on Flash
    );

int EXPORT canVerifyFirmware       // Verfiy Firmware on CAN Board
    (
    unsigned long       offset,    // Offset to Firmware section
    unsigned int        length,    // Lenght of section < 9
    unsigned char DIST* firmware   // Pointer to data
    );

int EXPORT canUpdateHwRevision    // Update Hardware Revision on CAN Board
    (
    unsigned int        version,  // Hardwareversion
    unsigned char DIST* key       // Key needed for Update
    );

#ifdef __cplusplus
}
#endif
